@@ -1,8 +1,7 @@
 //! Wrappers around various side effects.
 
 use bstr::ByteSlice;
-use std::convert::TryInto;
-use std::fmt::{Debug, Write};
+use std::fmt::{Debug, Display, Write};
 use std::io::{stderr, stdout, Stderr, Stdout, Write as WriteIo};
 use std::mem::take;
 use std::sync::{Arc, Mutex, RwLock};
@@ -51,45 +50,46 @@ pub enum OperationType {
     WalkCommits,
 }
 
-impl ToString for OperationType {
-    fn to_string(&self) -> String {
-        let s = match self {
-            OperationType::BuildRebasePlan => "Building rebase plan",
-            OperationType::CalculateDiff => "Computing diffs",
-            OperationType::CalculatePatchId => "Hashing commit contents",
-            OperationType::CheckForCycles => "Checking for cycles",
-            OperationType::ConstrainCommits => "Creating commit constraints",
-            OperationType::DetectDuplicateCommits => "Checking for duplicate commits",
+impl Display for OperationType {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            OperationType::BuildRebasePlan => write!(f, "Building rebase plan"),
+            OperationType::CalculateDiff => write!(f, "Computing diffs"),
+            OperationType::CalculatePatchId => write!(f, "Hashing commit contents"),
+            OperationType::CheckForCycles => write!(f, "Checking for cycles"),
+            OperationType::ConstrainCommits => write!(f, "Creating commit constraints"),
+            OperationType::DetectDuplicateCommits => write!(f, "Checking for duplicate commits"),
             OperationType::EvaluateRevset(revset) => {
-                return format!("Evaluating revset: {revset}");
+                write!(f, "Evaluating revset: {revset}")
             }
-            OperationType::FilterByTouchedPaths => "Filtering upstream commits by touched paths",
-            OperationType::FilterCommits => "Filtering commits",
-            OperationType::FindPathToMergeBase => "Finding path to merge-base",
-            OperationType::GetMergeBase => "Calculating merge-bases",
-            OperationType::GetTouchedPaths => "Getting touched paths",
-            OperationType::GetUpstreamPatchIds => "Enumerating patch IDs",
-            OperationType::InitializeRebase => "Initializing rebase",
-            OperationType::MakeGraph => "Examining local history",
-            OperationType::PushCommits => "Pushing branches",
-            OperationType::ProcessEvents => "Processing events",
-            OperationType::QueryWorkingCopy => "Querying the working copy",
-            OperationType::ReadingFromCache => "Reading from cache",
-            OperationType::RebaseCommits => "Rebasing commits",
-            OperationType::RepairBranches => "Checking for broken branches",
-            OperationType::RepairCommits => "Checking for broken commits",
+            OperationType::FilterByTouchedPaths => {
+                write!(f, "Filtering upstream commits by touched paths")
+            }
+            OperationType::FilterCommits => write!(f, "Filtering commits"),
+            OperationType::FindPathToMergeBase => write!(f, "Finding path to merge-base"),
+            OperationType::GetMergeBase => write!(f, "Calculating merge-bases"),
+            OperationType::GetTouchedPaths => write!(f, "Getting touched paths"),
+            OperationType::GetUpstreamPatchIds => write!(f, "Enumerating patch IDs"),
+            OperationType::InitializeRebase => write!(f, "Initializing rebase"),
+            OperationType::MakeGraph => write!(f, "Examining local history"),
+            OperationType::PushCommits => write!(f, "Pushing branches"),
+            OperationType::ProcessEvents => write!(f, "Processing events"),
+            OperationType::QueryWorkingCopy => write!(f, "Querying the working copy"),
+            OperationType::ReadingFromCache => write!(f, "Reading from cache"),
+            OperationType::RebaseCommits => write!(f, "Rebasing commits"),
+            OperationType::RepairBranches => write!(f, "Checking for broken branches"),
+            OperationType::RepairCommits => write!(f, "Checking for broken commits"),
             OperationType::RunGitCommand(command) => {
-                return format!("Running Git command: {}", &command)
+                write!(f, "Running Git command: {}", &command)
             }
-            OperationType::RunTests(command) => return format!("Running command: {command}"),
-            OperationType::RunTestOnCommit(commit) => return format!("Waiting to run on {commit}"),
-            OperationType::SortCommits => "Sorting commits",
-            OperationType::SyncCommits => "Syncing commit stacks",
-            OperationType::UpdateCommits => "Updating commits",
-            OperationType::UpdateCommitGraph => "Updating commit graph",
-            OperationType::WalkCommits => "Walking commits",
-        };
-        s.to_string()
+            OperationType::RunTests(command) => write!(f, "Running command: {command}"),
+            OperationType::RunTestOnCommit(commit) => write!(f, "Waiting to run on {commit}"),
+            OperationType::SortCommits => write!(f, "Sorting commits"),
+            OperationType::SyncCommits => write!(f, "Syncing commit stacks"),
+            OperationType::UpdateCommits => write!(f, "Updating commits"),
+            OperationType::UpdateCommitGraph => write!(f, "Updating commit graph"),
+            OperationType::WalkCommits => write!(f, "Walking commits"),
+        }
     }
 }
 
@@ -762,7 +762,7 @@ trait WriteProgress {
         // `ProgressBar` is included in a `MultiProgress`, it doesn't matter
         // which of them we call `println` on. The output will be printed above
         // the `MultiProgress` regardless.
-        let operation = root_operation.children.get(0);
+        let operation = root_operation.children.first();
         match operation {
             None => {
                 // There's no progress meters, so we can write directly to
@@ -829,13 +829,6 @@ trait WriteProgress {
     fn drop(&mut self) {
         let buffer = self.get_buffer();
         if !buffer.is_empty() {
-            // In practice, we're expecting that every sequence of `write` calls
-            // will shortly end with a `write` call that ends with a newline, in
-            // such a way that only full lines are written to the output stream.
-            // This assumption might be wrong, in which case we should revisit
-            // this warning and the behavior on `Drop`.
-            warn!(?buffer, "WriteProgress dropped while buffer was not empty");
-
             // NB: this only flushes completely-written lines, which is not
             // correct. We should flush the entire buffer contents, and possibly
             // force a newline at the end in the case of a progress meter being
@@ -1007,7 +1000,7 @@ impl Drop for ProgressHandle<'_> {
     }
 }
 
-impl ProgressHandle<'_> {
+impl<'a> ProgressHandle<'a> {
     /// Notify the progress meter that the current operation has `total`
     /// discrete units of work, and it's currently `current` units of the way
     /// through the operation.
@@ -1032,6 +1025,46 @@ impl ProgressHandle<'_> {
     }
 }
 
+/// A wrapper around an iterator that reports progress as it iterates.
+pub struct ProgressIter<'a, TItem, TInner: Iterator<Item = TItem>> {
+    index: usize,
+    inner: TInner,
+    progress: ProgressHandle<'a>,
+}
+
+impl<TItem, TInner: Iterator<Item = TItem>> Iterator for ProgressIter<'_, TItem, TInner> {
+    type Item = TItem;
+
+    fn next(&mut self) -> Option<Self::Item> {
+        let (lower, upper) = self.inner.size_hint();
+        let size_guess = upper.unwrap_or(lower);
+        self.progress.notify_progress(self.index, size_guess);
+        self.index += 1;
+        self.inner.next()
+    }
+}
+
+/// Extension trait for iterators that adds a `with_progress` method.
+pub trait WithProgress<'a, TItem>: Iterator<Item = TItem> {
+    /// The type of the iterator returned by `with_progress`.
+    type Iter: Iterator<Item = TItem> + 'a;
+
+    /// Wrap the iterator into an iterator that reports progress as it consumes items.
+    fn with_progress(self, progress: ProgressHandle<'a>) -> Self::Iter;
+}
+
+impl<'a, TItem: 'a, TIter: Iterator<Item = TItem> + 'a> WithProgress<'a, TItem> for TIter {
+    type Iter = ProgressIter<'a, TItem, TIter>;
+
+    fn with_progress(self, progress: ProgressHandle<'a>) -> Self::Iter {
+        ProgressIter {
+            index: 0,
+            inner: self,
+            progress,
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
