@@ -1,5 +1,6 @@
 //! Core algorithms and data structures.
 
+pub mod check_out;
 pub mod config;
 pub mod dag;
 pub mod effects;
@@ -7,5 +8,6 @@ pub mod eventlog;
 pub mod formatting;
 pub mod gc;
 pub mod node_descriptors;
+pub mod repo_ext;
 pub mod rewrite;
 pub mod task;
