@@ -46,9 +46,13 @@ fn test_drop_non_meaningful_events() -> eyre::Result<()> {
 fn test_different_event_transaction_ids() -> eyre::Result<()> {
     let git = make_git()?;
 
+    if git.produces_auto_merge_refs()? {
+        return Ok(());
+    }
+
     git.init_repo()?;
     git.commit_file("test1", 1)?;
-    git.branchless("hide", &["HEAD"])?;
+    git.branchless("hide", &["--no-delete-branches", "HEAD"])?;
 
     let repo = git.get_repo()?;
     let conn = repo.get_db_conn()?;
@@ -58,32 +62,32 @@ fn test_different_event_transaction_ids() -> eyre::Result<()> {
         events.iter().map(|event| event.get_event_tx_id()).collect();
     if git.supports_reference_transactions()? {
         insta::assert_debug_snapshot!(event_tx_ids, @r###"
-                [
-                    EventTransactionId(
-                        1,
-                    ),
-                    EventTransactionId(
-                        1,
-                    ),
-                    EventTransactionId(
-                        2,
-                    ),
-                    EventTransactionId(
-                        3,
-                    ),
-                ]
-                "###);
+        [
+            Id(
+                1,
+            ),
+            Id(
+                1,
+            ),
+            Id(
+                2,
+            ),
+            Id(
+                3,
+            ),
+        ]
+        "###);
     } else {
         insta::assert_debug_snapshot!(event_tx_ids, @r###"
-                [
-                    EventTransactionId(
-                        1,
-                    ),
-                    EventTransactionId(
-                        2,
-                    ),
-                ]
-                "###);
+        [
+            Id(
+                1,
+            ),
+            Id(
+                2,
+            ),
+        ]
+        "###);
     }
     Ok(())
 }
@@ -92,7 +96,7 @@ fn test_different_event_transaction_ids() -> eyre::Result<()> {
 fn test_advance_cursor_by_transaction() -> eyre::Result<()> {
     let mut event_replayer = new_event_replayer("refs/heads/master".into());
     for (timestamp, event_tx_id) in (0..).zip(&[1, 1, 2, 2, 3, 4]) {
-        let timestamp: f64 = timestamp.try_into()?;
+        let timestamp = f64::from(timestamp);
         event_replayer.process_event(&Event::UnobsoleteEvent {
             timestamp,
             event_tx_id: new_event_transaction_id(*event_tx_id),
