@@ -8,6 +8,9 @@
     clippy::dbg_macro
 )]
 #![allow(clippy::too_many_arguments, clippy::blocks_in_if_conditions)]
+// These URLs are printed verbatim in help output, so we don't want to add extraneous Markdown
+// formatting.
+#![allow(rustdoc::bare_urls)]
 
 use std::ffi::OsString;
 use std::fmt::Display;
@@ -358,11 +361,12 @@ pub struct SmartlogArgs {
 /// The Git hosting provider to use, called a "forge".
 #[derive(Clone, Debug, ValueEnum)]
 pub enum ForgeKind {
-    /// Force-push branches to the default push remote.
+    /// Force-push branches to the default push remote. You can configure the
+    /// default push remote with `git config remote.pushDefault <remote>`.
     Branch,
 
     /// Force-push branches to the remote and create a pull request for each
-    /// branch using the `gh` command-line tool.
+    /// branch using the `gh` command-line tool. WARNING: likely buggy!
     Github,
 
     /// Submit code reviews to Phabricator using the `arc` command-line tool.
@@ -372,25 +376,9 @@ pub enum ForgeKind {
 /// Push commits to a remote.
 #[derive(Debug, Parser)]
 pub struct SubmitArgs {
-    /// If there is no remote branch for a given local branch, create the
-    /// remote branch by pushing the local branch to the default push
-    /// remote.
-    ///
-    /// You can configure the default push remote with `git config
-    /// remote.pushDefault <remote>`.
-    #[clap(action, short = 'c', long = "create")]
-    pub create: bool,
-
-    /// If the remote supports it, create code reviews in "draft" mode.
-    #[clap(action, short = 'd', long = "draft")]
-    pub draft: bool,
-
-    /// What kind of execution strategy to use for tools which need access to the working copy.
-    #[clap(short = 's', long = "strategy")]
-    pub strategy: Option<TestExecutionStrategy>,
-
-    /// The commits to push. All branches attached to those commits will be
-    /// pushed.
+    /// The commits to push to the forge. Unless `--create` is passed, this will
+    /// only push commits that already have associated remote objects on the
+    /// forge.
     #[clap(value_parser, default_value = "stack()")]
     pub revsets: Vec<Revset>,
 
@@ -398,16 +386,40 @@ pub struct SubmitArgs {
     #[clap(flatten)]
     pub resolve_revset_options: ResolveRevsetOptions,
 
-    /// The Git hosting provider to use.
+    /// The Git hosting provider to use, called a "forge". If not provided, an
+    /// attempt will be made to automatically detect the forge used by the
+    /// repository. If no forge can be detected, will fall back to the "branch"
+    /// forge.
     #[clap(short = 'F', long = "forge")]
-    pub forge: Option<ForgeKind>,
+    pub forge_kind: Option<ForgeKind>,
 
-    /// An optional message to include with the create or update operation.
+    /// If there is no associated remote commit or code review object for a
+    /// given local commit, create the remote object by pushing the local commit
+    /// to the forge.
+    #[clap(action, short = 'c', long = "create")]
+    pub create: bool,
+
+    /// If the forge supports it, create code reviews in "draft" mode.
+    #[clap(action, short = 'd', long = "draft")]
+    pub draft: bool,
+
+    /// If the forge supports it, an optional message to include with the create
+    /// or update operation.
     #[clap(short = 'm', long = "message")]
     pub message: Option<String>,
 
+    /// If the forge supports it, how many jobs to execute in parallel. The
+    /// value `0` indicates to use all CPUs.
+    #[clap(short = 'j', long = "jobs")]
+    pub num_jobs: Option<usize>,
+
+    /// If the forge supports it and uses a tool that needs access to the
+    /// working copy, what kind of execution strategy to use.
+    #[clap(short = 's', long = "strategy")]
+    pub execution_strategy: Option<TestExecutionStrategy>,
+
     /// Don't push or create anything. Instead, report what would be pushed or
-    /// created. (Still triggers a fetch.)
+    /// created. (This may still trigger fetching information from the forge.)
     #[clap(short = 'n', long = "dry-run")]
     pub dry_run: bool,
 }
@@ -442,7 +454,7 @@ pub enum Command {
 
     /// Use the partial commit selector UI as a Git-compatible difftool; see
     /// git-difftool(1) for more information on Git difftools.
-    Difftool(scm_record::scm_diff_editor::Opts),
+    Difftool(scm_diff_editor::Opts),
 
     /// Run internal garbage collection.
     Gc,
@@ -774,7 +786,7 @@ pub struct GlobalArgs {
 
 /// Branchless workflow for Git.
 ///
-/// See the documentation at <https://github.com/arxanas/git-branchless/wiki>.
+/// See the documentation at https://github.com/arxanas/git-branchless/wiki.
 #[derive(Debug, Parser)]
 #[clap(version = env!("CARGO_PKG_VERSION"), author = "Waleed Khan <me@waleedkhan.name>")]
 pub struct Opts {
@@ -977,9 +989,10 @@ fn generate_man_page(man1_dir: &Path, name: &str, command: &ClapCommand) -> std:
     Ok(())
 }
 
-/// Carry out some rewrites on the command-line arguments for uniformity. For
-/// example, `git-branchless-smartlog` becomes `git-branchless smartlog`, and
-/// the `.exe` suffix is removed on Windows. These are necessary for later
+/// Carry out some rewrites on the command-line arguments for uniformity.
+///
+/// For example, `git-branchless-smartlog` becomes `git-branchless smartlog`,
+/// and the `.exe` suffix is removed on Windows. These are necessary for later
 /// command-line argument parsing.
 pub fn rewrite_args(args: Vec<OsString>) -> Vec<OsString> {
     let first_arg = match args.first() {
