@@ -16,9 +16,10 @@ use std::time::SystemTime;
 
 use git_branchless_invoke::CommandContext;
 use git_branchless_opts::RecordArgs;
+use git_branchless_reword::edit_message;
 use itertools::Itertools;
-use lib::core::check_out::{check_out_commit, CheckOutCommitOptions};
-use lib::core::config::get_restack_preserve_timestamps;
+use lib::core::check_out::{check_out_commit, CheckOutCommitOptions, CheckoutTarget};
+use lib::core::config::{get_commit_template, get_restack_preserve_timestamps};
 use lib::core::dag::{CommitSet, Dag};
 use lib::core::effects::{Effects, OperationType};
 use lib::core::eventlog::{EventLogDb, EventReplayer, EventTransactionId};
@@ -37,7 +38,10 @@ use lib::git::{
 use lib::try_exit_code;
 use lib::util::{ExitCode, EyreExitOr};
 use rayon::ThreadPoolBuilder;
-use scm_record::{EventSource, RecordError, RecordState, Recorder, SelectedContents};
+use scm_record::helpers::CrosstermInput;
+use scm_record::{
+    Commit, Event, RecordError, RecordInput, RecordState, Recorder, SelectedContents, TerminalKind,
+};
 use tracing::{instrument, warn};
 
 /// Commit changes in the working copy.
@@ -48,20 +52,22 @@ pub fn command_main(ctx: CommandContext, args: RecordArgs) -> EyreExitOr<()> {
         git_run_info,
     } = ctx;
     let RecordArgs {
-        message,
+        messages,
         interactive,
         create,
         detach,
         insert,
+        stash,
     } = args;
     record(
         &effects,
         &git_run_info,
-        message,
+        messages,
         interactive,
         create,
         detach,
         insert,
+        stash,
     )
 }
 
@@ -69,11 +75,12 @@ pub fn command_main(ctx: CommandContext, args: RecordArgs) -> EyreExitOr<()> {
 fn record(
     effects: &Effects,
     git_run_info: &GitRunInfo,
-    message: Option<String>,
+    messages: Vec<String>,
     interactive: bool,
     branch_name: Option<String>,
     detach: bool,
     insert: bool,
+    stash: bool,
 ) -> EyreExitOr<()> {
     let now = SystemTime::now();
     let repo = Repo::from_dir(&git_run_info.working_directory)?;
@@ -146,15 +153,13 @@ fn record(
                 &repo,
                 &snapshot,
                 event_tx_id,
-                message.as_deref(),
+                messages,
             )?);
         }
     } else {
         let args = {
             let mut args = vec!["commit"];
-            if let Some(message) = &message {
-                args.extend(["--message", message]);
-            }
+            args.extend(messages.iter().flat_map(|message| ["--message", message]));
             if working_copy_changes_type == WorkingCopyChangesType::Unstaged {
                 args.push("--all");
             }
@@ -163,7 +168,7 @@ fn record(
         try_exit_code!(git_run_info.run_direct_no_wrapping(Some(event_tx_id), &args)?);
     }
 
-    if detach {
+    if detach || stash {
         let head_info = repo.get_head_info()?;
         if let ResolvedReferenceInfo {
             oid: Some(oid),
@@ -171,8 +176,8 @@ fn record(
         } = &head_info
         {
             let head_commit = repo.find_commit_or_fail(*oid)?;
-            return match head_commit.get_parents().as_slice() {
-                [] => git_run_info.run(
+            match head_commit.get_parents().as_slice() {
+                [] => try_exit_code!(git_run_info.run(
                     effects,
                     Some(event_tx_id),
                     &[
@@ -181,12 +186,11 @@ fn record(
                         reference_name.as_str(),
                         &oid.to_string(),
                     ],
-                ),
+                )?),
                 [parent_commit] => {
-                    let branch_name =
-                        CategorizedReferenceName::new(reference_name).remove_prefix()?;
+                    let branch_name = CategorizedReferenceName::new(reference_name).render_suffix();
                     repo.detach_head(&head_info)?;
-                    git_run_info.run(
+                    try_exit_code!(git_run_info.run(
                         effects,
                         Some(event_tx_id),
                         &[
@@ -195,12 +199,38 @@ fn record(
                             &branch_name,
                             &parent_commit.get_oid().to_string(),
                         ],
-                    )
+                    )?);
                 }
                 parent_commits => {
                     eyre::bail!("git-branchless record --detach called on a merge commit, but it should only be capable of creating zero- or one-parent commits. Parents: {parent_commits:?}");
                 }
-            };
+            }
+        }
+        let checkout_target = match head_info {
+            ResolvedReferenceInfo {
+                oid: _,
+                reference_name: Some(reference_name),
+            } => Some(CheckoutTarget::Reference(reference_name.clone())),
+            ResolvedReferenceInfo {
+                oid: Some(oid),
+                reference_name: _,
+            } => Some(CheckoutTarget::Oid(oid)),
+            _ => None,
+        };
+        if stash && checkout_target.is_some() {
+            try_exit_code!(check_out_commit(
+                effects,
+                git_run_info,
+                &repo,
+                &event_log_db,
+                event_tx_id,
+                checkout_target,
+                &CheckOutCommitOptions {
+                    additional_args: vec![],
+                    reset: false,
+                    render_smartlog: false,
+                },
+            )?);
         }
     }
 
@@ -223,7 +253,7 @@ fn record_interactive(
     repo: &Repo,
     snapshot: &WorkingCopySnapshot,
     event_tx_id: EventTransactionId,
-    message: Option<&str>,
+    messages: Vec<String>,
 ) -> EyreExitOr<()> {
     let old_tree = snapshot.commit_stage0.get_tree()?;
     let new_tree = snapshot.commit_unstaged.get_tree()?;
@@ -240,13 +270,48 @@ fn record_interactive(
     };
     let record_state = RecordState {
         is_read_only: false,
+        commits: vec![
+            Commit {
+                message: Some(messages.iter().join("\n\n")),
+            },
+            Commit { message: None },
+        ],
         files,
     };
 
-    let recorder = Recorder::new(record_state, EventSource::Crossterm);
+    struct Input<'a> {
+        git_run_info: &'a GitRunInfo,
+        repo: &'a Repo,
+    }
+    impl RecordInput for Input<'_> {
+        fn terminal_kind(&self) -> TerminalKind {
+            TerminalKind::Crossterm
+        }
+
+        fn next_events(&mut self) -> Result<Vec<Event>, RecordError> {
+            CrosstermInput.next_events()
+        }
+
+        fn edit_commit_message(&mut self, message: &str) -> Result<String, RecordError> {
+            let Self { git_run_info, repo } = self;
+            let commit_template = get_commit_template(repo).map_err(|err| {
+                RecordError::Other(format!("Could not read commit message template: {err}",))
+            })?;
+            let message = if message.is_empty() {
+                commit_template.as_deref().unwrap_or("")
+            } else {
+                message
+            };
+            edit_message(git_run_info, repo, message)
+                .map_err(|err| RecordError::Other(err.to_string()))
+        }
+    }
+    let mut input = Input { git_run_info, repo };
+    let recorder = Recorder::new(record_state, &mut input);
     let result = recorder.run();
     let RecordState {
         is_read_only: _,
+        commits,
         files: result,
     } = match result {
         Ok(result) => result,
@@ -265,12 +330,14 @@ fn record_interactive(
             | RecordError::ReadInput(_)
             | RecordError::RenderFrame(_)
             | RecordError::SerializeJson(_)
-            | RecordError::WriteFile(_)),
+            | RecordError::WriteFile(_)
+            | RecordError::Other(_)),
         ) => {
             println!("Error: {err}");
             return Ok(Err(ExitCode(1)));
         }
     };
+    let message = commits[0].message.clone().unwrap_or_default();
 
     let update_index_script: Vec<UpdateIndexCommand> = result
         .into_iter()
@@ -340,8 +407,8 @@ fn record_interactive(
 
     let args = {
         let mut args = vec!["commit"];
-        if let Some(message) = message {
-            args.extend(["--message", message]);
+        if !message.is_empty() {
+            args.extend(["--message", &message]);
         }
         args
     };
