@@ -3,15 +3,15 @@ use eden_dag::nameset::hints::Hints;
 
 use lib::core::dag::CommitSet;
 use lib::core::eventlog::{EventLogDb, EventReplayer};
+use lib::core::repo_ext::RepoExt;
 use lib::core::rewrite::find_rewrite_target;
 use lib::git::{
-    get_latest_test_command_path, get_test_tree_dir, Commit, MaybeZeroOid, Repo,
-    SerializedNonZeroOid, SerializedTestResult, TEST_ABORT_EXIT_CODE, TEST_INDETERMINATE_EXIT_CODE,
-    TEST_SUCCESS_EXIT_CODE,
+    get_latest_test_command_path, get_test_tree_dir, CategorizedReferenceName, Commit,
+    MaybeZeroOid, Repo, SerializedNonZeroOid, SerializedTestResult, TEST_ABORT_EXIT_CODE,
+    TEST_INDETERMINATE_EXIT_CODE, TEST_SUCCESS_EXIT_CODE,
 };
 use std::borrow::Cow;
 use std::collections::HashMap;
-use std::convert::TryFrom;
 use tracing::{instrument, warn};
 
 use eyre::Context as EyreContext;
@@ -61,6 +61,7 @@ lazy_static! {
             ("committer.date", &fn_committer_date),
             ("exactly", &fn_exactly),
             ("current", &fn_current),
+            ("merges", &fn_merges),
             ("tests.passed", &fn_tests_passed),
             ("tests.failed", &fn_tests_failed),
             ("tests.fixable", &fn_tests_fixable),
@@ -178,8 +179,48 @@ fn fn_heads(ctx: &mut Context, name: &str, args: &[Expr]) -> EvalResult {
 
 #[instrument]
 fn fn_branches(ctx: &mut Context, name: &str, args: &[Expr]) -> EvalResult {
-    eval0(ctx, name, args)?;
-    Ok(ctx.dag.branch_commits.clone())
+    let pattern = match eval0_or_1_pattern(ctx, name, args)? {
+        Some(pattern) => pattern,
+        None => return Ok(ctx.dag.branch_commits.clone()),
+    };
+
+    let branch_oid_to_names = ctx
+        .repo
+        .get_references_snapshot()
+        .wrap_err("Could not get references snapshot for repo")
+        .map_err(EvalError::OtherError)?
+        .branch_oid_to_names;
+
+    let branch_commits = make_pattern_matcher_for_set(
+        ctx,
+        name,
+        args,
+        Box::new(move |_repo, commit| {
+            let branches_at_commit = match branch_oid_to_names.get(&commit.get_oid()) {
+                Some(branches) => branches,
+                None => return Ok(false),
+            };
+
+            let result = branches_at_commit
+                .iter()
+                .filter_map(
+                    |branch_name| match CategorizedReferenceName::new(branch_name) {
+                        name @ CategorizedReferenceName::LocalBranch { .. } => {
+                            Some(name.render_suffix())
+                        }
+                        // we only care about local branches
+                        CategorizedReferenceName::RemoteBranch { .. }
+                        | CategorizedReferenceName::OtherRef { .. } => None,
+                    },
+                )
+                .any(|branch_name| pattern.matches_text(branch_name.as_str()));
+
+            Ok(result)
+        }),
+        Some(ctx.dag.branch_commits.clone()),
+    )?;
+
+    Ok(branch_commits)
 }
 
 #[instrument]
@@ -248,38 +289,31 @@ fn fn_draft(ctx: &mut Context, name: &str, args: &[Expr]) -> EvalResult {
 #[instrument]
 fn fn_stack(ctx: &mut Context, name: &str, args: &[Expr]) -> EvalResult {
     let arg = eval0_or_1(ctx, name, args)?.unwrap_or_else(|| ctx.dag.head_commit.clone());
-    let draft_commits = ctx
-        .dag
-        .query_draft_commits()
-        .map_err(EvalError::OtherError)?;
-    let stack_roots = ctx.dag.query_roots(draft_commits.clone())?;
-    let stack_ancestors = ctx.dag.query_range(stack_roots, arg)?;
-    let stack = ctx
-        .dag
-        // Note that for a graph like
-        //
-        // ```
-        // O
-        // |
-        // o A
-        // | \
-        // |  o B
-        // |
-        // @ C
-        // ```
-        // this will return `{A, B, C}`, not just `{A, C}`.
-        .query_range(stack_ancestors, draft_commits.clone())?;
-    Ok(stack)
+    ctx.dag
+        .query_stack_commits(arg)
+        .map_err(EvalError::OtherError)
 }
 
 type MatcherFn = dyn Fn(&Repo, &Commit) -> Result<bool, PatternError> + Sync + Send;
 
-#[instrument(skip(f))]
+/// Make a pattern matcher that operates on all visible commits.
 fn make_pattern_matcher(
     ctx: &mut Context,
     name: &str,
     args: &[Expr],
     f: Box<MatcherFn>,
+) -> Result<CommitSet, EvalError> {
+    make_pattern_matcher_for_set(ctx, name, args, f, None)
+}
+
+/// Make a pattern matcher that operates only on the given set of commits.
+#[instrument(skip(f))]
+fn make_pattern_matcher_for_set(
+    ctx: &mut Context,
+    name: &str,
+    args: &[Expr],
+    f: Box<MatcherFn>,
+    commits_to_match: Option<CommitSet>,
 ) -> Result<CommitSet, EvalError> {
     struct Matcher {
         expr: String,
@@ -300,7 +334,7 @@ fn make_pattern_matcher(
         expr: Expr::FunctionCall(Cow::Borrowed(name), args.to_vec()).to_string(),
         f,
     };
-    let matcher = make_pattern_matcher_set(ctx, ctx.repo, Box::new(matcher))?;
+    let matcher = make_pattern_matcher_set(ctx, ctx.repo, Box::new(matcher), commits_to_match)?;
     Ok(matcher)
 }
 
@@ -338,17 +372,9 @@ fn fn_path_changed(ctx: &mut Context, name: &str, args: &[Expr]) -> EvalResult {
         name,
         args,
         Box::new(move |repo: &Repo, commit: &Commit| {
-            let touched_paths = match repo
+            let touched_paths = repo
                 .get_paths_touched_by_commit(commit)
-                .map_err(PatternError::Repo)?
-            {
-                Some(touched_paths) => touched_paths,
-                None => {
-                    // FIXME: it might be more intuitive to check all changed
-                    // paths with respect to any parent.
-                    return Ok(false);
-                }
-            };
+                .map_err(PatternError::Repo)?;
             let result = touched_paths.into_iter().any(|path| {
                 let path = match path.to_str() {
                     Some(path) => path,
@@ -521,8 +547,21 @@ fn fn_current(ctx: &mut Context, name: &str, args: &[Expr]) -> EvalResult {
     Ok(result.into_iter().collect::<CommitSet>())
 }
 
+#[instrument]
+fn fn_merges(ctx: &mut Context, name: &str, args: &[Expr]) -> EvalResult {
+    eval0(ctx, name, args)?;
+    // Use a "pattern matcher" that – instead of testing for a pattern –
+    // examines the parent count of each commit to find merges.
+    make_pattern_matcher(
+        ctx,
+        name,
+        args,
+        Box::new(move |_repo, commit| Ok(commit.get_parent_count() > 1)),
+    )
+}
+
 fn read_all_test_results(repo: &Repo, commit: &Commit) -> Option<Vec<SerializedTestResult>> {
-    let commit_test_dir = get_test_tree_dir(repo, commit);
+    let commit_test_dir = get_test_tree_dir(repo, commit).ok()?;
     let mut all_results = Vec::new();
     for dir in std::fs::read_dir(commit_test_dir).ok()? {
         let dir = dir.ok()?;
@@ -537,7 +576,7 @@ fn read_all_test_results(repo: &Repo, commit: &Commit) -> Option<Vec<SerializedT
 }
 
 fn read_latest_test_command(repo: &Repo) -> Option<String> {
-    let latest_command_path = get_latest_test_command_path(repo);
+    let latest_command_path = get_latest_test_command_path(repo).ok()?;
     let latest_command = std::fs::read_to_string(latest_command_path).ok()?;
     Some(latest_command)
 }
