@@ -58,6 +58,29 @@ pub enum InitialCommitMessages {
     Messages(Vec<String>),
 }
 
+/// Open the user's configured commit editor seeded with the provided message.
+#[instrument]
+pub fn edit_message(git_run_info: &GitRunInfo, repo: &Repo, message: &str) -> eyre::Result<String> {
+    let (mut editor, editor_program) = match get_editor(git_run_info, repo)? {
+        Some(editor_program) => {
+            let mut editor = Editor::new();
+            editor.executable(&editor_program);
+            (editor, editor_program)
+        }
+        None => (Editor::new(), "<default>".into()),
+    };
+    if editor_program == ":" {
+        // Special case in Git: treat `:` as a no-op editor.
+        return Ok(message.to_string());
+    }
+    let result = editor
+        .require_save(false)
+        .edit(message)
+        .with_context(|| format!("Invoking editor: '{}'", editor_program.to_string_lossy()))?
+        .expect("`Editor::edit` should not return `None` when `require_save` is `false`");
+    Ok(result)
+}
+
 /// Reword a commit and restack its descendants.
 #[instrument]
 pub fn reword(
@@ -152,25 +175,7 @@ pub fn reword(
         }
     };
 
-    #[instrument]
-    fn edit_message_fn_inner(
-        git_run_info: &GitRunInfo,
-        repo: &Repo,
-        message: &str,
-    ) -> eyre::Result<String> {
-        let mut editor = Editor::new();
-        let (editor, editor_program) = match get_editor(git_run_info, repo)? {
-            Some(editor_program) => (editor.executable(&editor_program), editor_program),
-            None => (&mut editor, "<default>".into()),
-        };
-        let result = editor
-            .require_save(false)
-            .edit(message)
-            .with_context(|| format!("Invoking editor: '{}'", editor_program.to_string_lossy()))?
-            .expect("`Editor::edit` should not return `None` when `require_save` is `false`");
-        Ok(result)
-    }
-    let edit_message_fn = |message: &str| edit_message_fn_inner(git_run_info, &repo, message);
+    let edit_message_fn = |message: &str| edit_message(git_run_info, &repo, message);
 
     let messages = match prepare_messages(&repo, messages, &commits, edit_message_fn)? {
         PrepareMessagesResult::Succeeded { messages } => messages,
@@ -462,8 +467,9 @@ fn prepare_messages(
     message.push_str(
         format!(
             "\
-                {} Rewording: Please enter the commit {} to apply to {}. Lines\n\
-                {} starting with '{}' will be ignored, and an empty message aborts rewording.",
+                {} Rewording: Please enter the commit {} to apply to {}.\n\
+                {} Lines starting with '{}' will be ignored, and an empty message aborts\n\
+                {} rewording.",
             comment_char,
             match commits.len() {
                 1 => "message",
@@ -476,6 +482,7 @@ fn prepare_messages(
             },
             comment_char,
             comment_char,
+            comment_char,
         )
         .as_str(),
     );
@@ -719,12 +726,12 @@ mod tests {
                 &[head_commit.clone()],
                 |message| {
                     insta::assert_snapshot!(message.trim(), @r###"
-
                     # Original message:
                     # create test1.txt
 
-                    # Rewording: Please enter the commit message to apply to this 1 commit. Lines
-                    # starting with '#' will be ignored, and an empty message aborts rewording.
+                    # Rewording: Please enter the commit message to apply to this 1 commit.
+                    # Lines starting with '#' will be ignored, and an empty message aborts
+                    # rewording.
                     "###);
                     Ok(message.to_string())
                 },
@@ -752,8 +759,9 @@ This is a template!
                     # Original message:
                     # create test1.txt
 
-                    # Rewording: Please enter the commit message to apply to this 1 commit. Lines
-                    # starting with '#' will be ignored, and an empty message aborts rewording.
+                    # Rewording: Please enter the commit message to apply to this 1 commit.
+                    # Lines starting with '#' will be ignored, and an empty message aborts
+                    # rewording.
                     "###);
                     Ok(message.to_string())
                 },
@@ -788,8 +796,9 @@ This is a template!
                     ++ reword 96d1c37
                     create test2.txt
 
-                    # Rewording: Please enter the commit messages to apply to these 2 commits. Lines
-                    # starting with '#' will be ignored, and an empty message aborts rewording.
+                    # Rewording: Please enter the commit messages to apply to these 2 commits.
+                    # Lines starting with '#' will be ignored, and an empty message aborts
+                    # rewording.
                     "###);
                     Ok(message.to_string())
                 },
