@@ -186,13 +186,14 @@ pub fn command_main(ctx: CommandContext, args: SubmitArgs) -> EyreExitOr<()> {
         git_run_info,
     } = ctx;
     let SubmitArgs {
-        create,
-        draft,
-        strategy,
         revsets,
         resolve_revset_options,
-        forge,
+        forge_kind,
+        create,
+        draft,
         message,
+        num_jobs,
+        execution_strategy,
         dry_run,
     } = args;
     submit(
@@ -200,11 +201,12 @@ pub fn command_main(ctx: CommandContext, args: SubmitArgs) -> EyreExitOr<()> {
         &git_run_info,
         revsets,
         &resolve_revset_options,
+        forge_kind,
         create,
         draft,
-        strategy,
-        forge,
         message,
+        num_jobs,
+        execution_strategy,
         dry_run,
     )
 }
@@ -214,11 +216,12 @@ fn submit(
     git_run_info: &GitRunInfo,
     revsets: Vec<Revset>,
     resolve_revset_options: &ResolveRevsetOptions,
+    forge_kind: Option<ForgeKind>,
     create: bool,
     draft: bool,
-    execution_strategy: Option<TestExecutionStrategy>,
-    forge_kind: Option<ForgeKind>,
     message: Option<String>,
+    num_jobs: Option<usize>,
+    execution_strategy: Option<TestExecutionStrategy>,
     dry_run: bool,
 ) -> EyreExitOr<()> {
     let repo = Repo::from_current_dir()?;
@@ -253,7 +256,7 @@ fn submit(
         bisect: false,
         no_cache: true,
         interactive: false,
-        jobs: None,
+        jobs: num_jobs,
         verbosity: Verbosity::None,
         apply_fixes: false,
     };
