@@ -1,6 +1,6 @@
 //! Utilities to control output and render to the terminal.
 
 mod cursive;
+pub mod testing;
 
 pub use self::cursive::{with_siv, SingletonView};
-pub use git_record::testing;
