@@ -828,8 +828,9 @@ fn test_undo_noninteractive() -> eyre::Result<()> {
     git.branchless("wrap", &["--", "commit", "--amend", "-m", "bad message"])?;
 
     {
-        let (stdout, _stderr) = git.run_with_options(
-            &["undo"],
+        let (stdout, _stderr) = git.branchless_with_options(
+            "undo",
+            &[],
             &GitRunOptions {
                 expected_exit_code: 1,
                 input: Some("n".to_string()),
@@ -860,8 +861,9 @@ fn test_undo_noninteractive() -> eyre::Result<()> {
     }
 
     {
-        let (stdout, _stderr) = git.run_with_options(
-            &["undo"],
+        let (stdout, _stderr) = git.branchless_with_options(
+            "undo",
+            &[],
             &GitRunOptions {
                 input: Some("y".to_string()),
                 ..Default::default()
@@ -925,7 +927,7 @@ fn test_undo_no_confirm() -> eyre::Result<()> {
 fn test_undo_unseen_commit() -> eyre::Result<()> {
     // Disabled since we no longer support `origin/master` as a main branch, but this test might be
     // useful in the future.
-    if cfg!(none) {
+    if false {
         let git = make_git()?;
         if !git.supports_reference_transactions()? {
             return Ok(());
